@@ -7,6 +7,7 @@ from collections.abc import Mapping
 from functools import partial
 
 import numpy as np
+from sklearn.base import BaseEstimator
 from sklearn.exceptions import NotFittedError
 from sklearn.utils.validation import check_is_fitted as sk_check_is_fitted
 import torch
@@ -211,7 +212,7 @@ def add_grad_hooks(net, match_fn=None):
     return recs_grad, recs_param_update, handles
 
 
-class SkorchDoctor:
+class SkorchDoctor(BaseEstimator):
     """SkorchDoctor helps you better understand and debug neural net training.
 
     By providing records activations, gradienst, and parameter updates, as well
@@ -440,6 +441,14 @@ class SkorchDoctor:
         self.fitted_ = True
         return self
 
+    def __sklearn_is_fitted__(self):
+        """This method is called when sklearn's ``check_is_fitted`` is used.
+
+        Explained here:
+        https://scikit-learn.org/stable/auto_examples/developing_estimators/sklearn_is_fitted.html
+        """
+        return getattr(self, "fitted_", False)
+
     def get_layer_names(self):
         """Return the names of all layers/modules
 
